searchData={"items":[{"type":"module","title":"Useful","doc":"A Library of `Useful` functions for building `Elixir` Apps.","ref":"Useful.html"},{"type":"function","title":"Useful.atomize_map_keys/1","doc":"`atomize_map_keys/1` converts a `Map` with different keys\nto a map with just atom keys. Works recursively for nested maps.\nInspired by stackoverflow.com/questions/31990134","ref":"Useful.html#atomize_map_keys/1"},{"type":"function","title":"Examples - Useful.atomize_map_keys/1","doc":"iex> Useful.atomize_map_keys(%{\"name\" => \"alex\", id: 1})\n    %{id: 1, name: \"alex\"}\n\n    iex> Useful.atomize_map_keys(%{\"name\" => \"alex\", data: %{ \"age\" => 17}})\n    %{name: \"alex\", data: %{age: 17}}","ref":"Useful.html#atomize_map_keys/1-examples"},{"type":"function","title":"Useful.empty_dir_contents/1","doc":"`empty_dir_contents/1` delete all files including any directories\nrecursively in a dir but not the dir itself.\n\nVery happy for anyone to refactor this function to something pretty.","ref":"Useful.html#empty_dir_contents/1"},{"type":"function","title":"Useful.flatten_map/1","doc":"`flatten_map/1` flattens a `Map` of any depth/nesting for easier processing.\nDeeply nested maps are denoted by \"__\" (double underscore) e.g:\n`%{name: Alex, detail: %{age: 17}}` becomes `%{name: Alex, detail__age: 17}`\nthis makes it easy to see what the data structure was before flattening.\nMap keys are converted to Atom for simpler access and consistency.\nInspired by: https://stackoverflow.com/questions/39401947/flatten-nested-map","ref":"Useful.html#flatten_map/1"},{"type":"function","title":"Examples - Useful.flatten_map/1","doc":"iex> map = %{name: \"alex\", data: %{age: 17, height: 185}}\n    iex> Useful.flatten_map(map)\n    %{data__age: 17, data__height: 185, name: \"alex\"}","ref":"Useful.html#flatten_map/1-examples"},{"type":"function","title":"Useful.get_in_default/3","doc":"`get_in_default/3` Proxies `Kernel.get_in/2`\nbut allows setting a `default` value as the 3rd argument.","ref":"Useful.html#get_in_default/3"},{"type":"function","title":"Examples - Useful.get_in_default/3","doc":"iex> map = %{name: \"alex\", data: %{age: 17, height: 185}}\n    iex> Useful.get_in_default(map, [:data, :age])\n    17\n    iex> Useful.get_in_default(map, [:data, :iq], 180)\n    180\n    iex> Useful.get_in_default(nil, [:unhappy, :path], \"Happy!\")\n    \"Happy!\"","ref":"Useful.html#get_in_default/3-examples"},{"type":"function","title":"Useful.list_tuples_to_unique_keys/1","doc":"`list_tuples_to_unique_keys/1` turns a list of tuples\nwith the same key into a list of tuples with unique keys.\nUseful when dealing with \"multipart\" forms that upload multiple files.","ref":"Useful.html#list_tuples_to_unique_keys/1"},{"type":"function","title":"Example - Useful.list_tuples_to_unique_keys/1","doc":"iex> parts = [{\"file\", \"header\", \"pic1.png\"}, {\"file\", \"header\", \"pic2.png\"}]\n    iex> Useful.list_tuples_to_unique_keys(parts)\n    [{\"file-1\", \"header\", \"pic1.png\"}, {\"file-2\", \"header\", \"pic2.png\"}]","ref":"Useful.html#list_tuples_to_unique_keys/1-example"},{"type":"function","title":"Useful.remove_item_from_list/2","doc":"`remove_item_from_list/2` removes a given `item` from a `list` in any position.","ref":"Useful.html#remove_item_from_list/2"},{"type":"function","title":"Examples - Useful.remove_item_from_list/2","doc":"iex> list = [\"They'll\", \"never\", \"take\", \"our\", \"freedom!\"]\n    iex> Useful.remove_item_from_list(list, \"never\")\n    [\"They'll\", \"take\", \"our\", \"freedom!\"]","ref":"Useful.html#remove_item_from_list/2-examples"},{"type":"function","title":"Useful.stringify_map/1","doc":"`stringy_map/1` converts a `Map` of any depth/nesting into a string.\nDeeply nested maps are denoted by \"__\" (double underscore). See flatten_map/1\nfor more details.\nAlphabetizes the keys for consistency. See: github.com/dwyl/useful/issues/56","ref":"Useful.html#stringify_map/1"},{"type":"function","title":"Examples - Useful.stringify_map/1","doc":"iex> map = %{name: \"alex\", data: %{age: 17, height: 185}}\n    iex> Useful.stringify_map(map)\n    \"data__age: 17, data__height: 185, name: alex\"","ref":"Useful.html#stringify_map/1-examples"},{"type":"function","title":"Useful.stringify_tuple/1","doc":"`stringify_tuple/1` stringifies a `Tuple` with arbitrary values.\nHandy when you want to print out a tuple during debugging.","ref":"Useful.html#stringify_tuple/1"},{"type":"function","title":"Examples - Useful.stringify_tuple/1","doc":"iex> tuple = {:name, \"alex\"}\n    iex> Useful.stringify_tuple(tuple)\n    \"name: alex\"","ref":"Useful.html#stringify_tuple/1-examples"},{"type":"function","title":"Useful.typeof/1","doc":"`typeof/1` returns the type of a vairable.\nInspired by stackoverflow.com/questions/28377135/check-typeof-variable-in-elixir","ref":"Useful.html#typeof/1"},{"type":"function","title":"Examples - Useful.typeof/1","doc":"iex> Useful.typeof(:atom)\n    \"atom\"\n\n    iex> bin = \"hello\"\n    iex> Useful.typeof(bin)\n    \"binary\"\n\n    iex> bitstr =  >\n    iex> Useful.typeof(bitstr)\n    \"bitstring\"\n\n    iex> Useful.typeof(:true)\n    \"boolean\"\n\n    iex> pi = 3.14159\n    iex> Useful.typeof(pi)\n    \"float\"\n\n    iex> fun = fn (a, b) -> a + b end\n    iex> Useful.typeof(fun)\n    \"function\"\n\n    iex> Useful.typeof(&Useful.typeof/1)\n    \"function\"\n\n    iex> int = 42\n    iex> Useful.typeof(int)\n    \"integer\"\n\n    iex> list = [1,2,3,4]\n    iex> Useful.typeof(list)\n    \"list\"\n\n    iex> map = %{:foo => \"bar\", \"hello\" => :world}\n    iex> Useful.typeof(map)\n    \"map\"\n\n    iex> Useful.typeof(nil)\n    \"nil\"\n\n    iex> pid = spawn(fn -> 1 + 2 end)\n    iex> Useful.typeof(pid)\n    \"pid\"\n\n    iex> port = Port.open({:spawn, \"cat\"}, [:binary])\n    iex> Useful.typeof(port)\n    \"port\"\n\n    iex> ref = :erlang.make_ref\n    iex> Useful.typeof(ref)\n    \"reference\"\n\n    iex> tuple = {:name, \"alex\"}\n    iex> Useful.typeof(tuple)\n    \"tuple\"","ref":"Useful.html#typeof/1-examples"}],"content_type":"text/markdown"}